# SRMASV Protobuf Library
------

[![Build Status](https://travis-ci.com/akashp1997/asv_protobuf.svg?token=aTEz3cwmJvzJj3hg2WkN&branch=master)](https://travis-ci.com/akashp1997/asv_protobuf)
------
This repository contains the SRMASV protobuf library.
------
## You can install with the following commands:
`pip install asvprotobuf`

The following module contains the following messages implemented in Google Protobuf:

#### asvprotobuf.std
-----
- [x] Header
- [x] Orientation
- [x] Vector
- [x] Log
- [x] Graph

#### asvprotobuf.sensor
-----
- [x] Imu
- [x] GPSFix
- [x] Image
- [x] LaserScan
- [x] Raw
- [x] PWM

#### asvprotobuf.nav
-----
- [x] Pose
- [x] Odometry
